# TransmissionRPC Readme


## Introduction


this project is forked from https://bitbucket.org/blueluna/transmission_rpc/overview

transmission-rpc is a python module implementing the json-rpc client protocol
for the BitTorrent client Transmission.

transmission-rpc is licensed under the MIT license.

## Requirements

transmission_rpc requires:

 * Python >= 3.4 or Python >=2.7,<3.0
 * Six >= 1.1.0, https://pypi.python.org/pypi/six/

## Install
```bash
$ pip install transmission-rpc
```

NOTE: You might need administrator privileges to install python modules.

The setup program will take care of the simplejson requirement.

## Documents

I'm still writing documents.

## Developer

transmission-rpc is hosted by GitHub at https://github.com/Trim21/transmission-rpc

Copyright (c) 2018 Trim21.

